@@ -2,7 +2,7 @@
 package Net::Simplify;
 
 =head1 NAME
- 
+
 Net::Simplify - Simplify Commerce Payments API
 
 =head1 SYNOPSIS
@@ -90,10 +90,12 @@ L<Net::Simplify::Deposit>,
 L<Net::Simplify::Event>,
 L<Net::Simplify::Event>,
 L<Net::Simplify::FieldError>,
+L<Net::Simplify::FraudCheck>,
 L<Net::Simplify::IllegalArgumentException>,
 L<Net::Simplify::Invoice>,
 L<Net::Simplify::InvoiceItem>,
 L<Net::Simplify::Tax>,
+L<Net::Simplify::TransactionReview>,
 L<Net::Simplify::NotAllowedException>,
 L<Net::Simplify::ObjectNotFoundException>,
 L<Net::Simplify::Payment>,
@@ -106,11 +108,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.1.0
+1.2.0
 
 =head1 LICENSE
 
-Copyright (c) 2013, 2014 MasterCard International Incorporated
+Copyright (c) 2013 - 2015 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
@@ -170,6 +172,7 @@ use Net::Simplify::Constants;
 use Net::Simplify::Coupon;
 use Net::Simplify::Customer;
 use Net::Simplify::Deposit;
+use Net::Simplify::FraudCheck;
 use Net::Simplify::Invoice;
 use Net::Simplify::InvoiceItem;
 use Net::Simplify::Tax;
@@ -177,6 +180,7 @@ use Net::Simplify::Payment;
 use Net::Simplify::Plan;
 use Net::Simplify::Refund;
 use Net::Simplify::Subscription;
+use Net::Simplify::TransactionReview;
 use Net::Simplify::Webhook;
 
 1;
