@@ -58,7 +58,7 @@ Address of the cardholder if needed. [max length: 255]
 
 =item card.addressState
 
-State code (USPS code) of residence of the cardholder. [max length: 2, min length: 2] 
+State of residence of the cardholder. For the US, this is a 2-digit USPS code. [max length: 255, min length: 2] 
 
 =item card.addressZip
 
@@ -74,7 +74,7 @@ Expiration month of the card. Format is MM. Example: January = 01 [min value: 1,
 
 =item card.expYear
 
-Expiration year of the card. Format is YY. Example: 2013 = 13 [max value: 99] (B<required>) 
+Expiration year of the card. Format is YY. Example: 2013 = 13 [min value: 0, max value: 99] (B<required>) 
 
 =item card.name
 
@@ -132,11 +132,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.1.0
+1.2.0
 
 =head1 LICENSE
 
-Copyright (c) 2013, 2014 MasterCard International Incorporated
+Copyright (c) 2013 - 2015 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
