@@ -51,7 +51,7 @@ Hash map containing initial values for the object.  Valid keys are:
 
 =item amountOff
 
-Amount off of the price of the product in the smallest units of the currency of the merchant. While this field is optional, you must provide either amountOff or percentOff for a coupon. Example: 100 = $1.00USD [min value: 1, max value: 9999900] 
+Amount off of the price of the product in the smallest units of the currency of the merchant. While this field is optional, you must provide either amountOff or percentOff for a coupon. Example: 100 = $1.00USD [min value: 1] 
 
 =item couponCode
 
@@ -63,7 +63,7 @@ A brief section that describes the coupon.
 
 =item durationInMonths
 
-Duration in months that the coupon will be applied after it has first been selected. [min value: 1, max value: 9999] 
+DEPRECATED - Duration in months that the coupon will be applied after it has first been selected. [min value: 1, max value: 9999] 
 
 =item endDate
 
@@ -73,6 +73,10 @@ Last date of the coupon in UTC millis that the coupon can be applied to a subscr
 
 Maximum number of redemptions allowed for the coupon. A redemption is defined as when the coupon is applied to the subscription for the first time. [min value: 1] 
 
+=item numTimesApplied
+
+The number of times a coupon will be applied on a customer's subscription. [min value: 1, max value: 9999] 
+
 =item percentOff
 
 Percentage off of the price of the product. While this field is optional, you must provide either amountOff or percentOff for a coupon. The percent off is a whole number. [min value: 1, max value: 100] 
@@ -120,13 +124,13 @@ Filters to apply to the list.
 
 =item C<max>
 
-Allows up to a max of 50 list items to return. [max value: 50, default: 20]
+Allows up to a max of 50 list items to return. [min value: 0, max value: 50, default: 20]
 
 
 
 =item C<offset>
 
-Used in paging of the list.  This is the start offset of the page. [default: 0]
+Used in paging of the list.  This is the start offset of the page. [min value: 0, default: 0]
 
 
 
@@ -155,6 +159,8 @@ The value maps properties to the sort direction (either C<asc> for ascending or
 
 =item C<durationInMonths>
 
+=item C<numTimesApplied>
+
 =item C<amountOff>
 
 
@@ -224,11 +230,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.1.0
+1.2.0
 
 =head1 LICENSE
 
-Copyright (c) 2013, 2014 MasterCard International Incorporated
+Copyright (c) 2013 - 2015 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
