@@ -69,7 +69,7 @@ Address of the cardholder if needed. (B<required>)
 
 =item card.addressState
 
-State code (USPS code) of residence of the cardholder. (B<required>) 
+State of residence of the cardholder. For the US, this is a 2-digit USPS code. (B<required>) 
 
 =item card.addressZip
 
@@ -115,7 +115,15 @@ Reference field for external applications use.
 
 =item subscriptions.amount
 
-Amount of payment in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 50, max value: 9999900] 
+Amount of payment in the smallest unit of your currency. Example: 100 = $1.00USD 
+
+=item subscriptions.billingCycle
+
+How the plan is billed to the customer. Values must be AUTO (indefinitely until the customer cancels) or FIXED (a fixed number of billing cycles). [default: AUTO] 
+
+=item subscriptions.billingCycleLimit
+
+The number of fixed billing cycles for a plan. Only used if the billingCycle parameter is set to FIXED. Example: 4 
 
 =item subscriptions.coupon
 
@@ -131,7 +139,11 @@ The customer ID to create the subscription for. Do not supply this when creating
 
 =item subscriptions.frequency
 
-Frequency of payment for the plan. Example: Monthly 
+Frequency of payment for the plan. Used in conjunction with frequencyPeriod. Valid values are "DAILY", "WEEKLY", "MONTHLY" and "YEARLY". 
+
+=item subscriptions.frequencyPeriod
+
+Period of frequency of payment for the plan. Example: if the frequency is weekly, and periodFrequency is 2, then the subscription is billed bi-weekly. 
 
 =item subscriptions.name
 
@@ -145,6 +157,10 @@ The plan ID that the subscription should be created from.
 
 Quantity of the plan for the subscription. [min value: 1] 
 
+=item subscriptions.renewalReminderLeadDays
+
+If set, how many days before the next billing cycle that a renewal reminder is sent to the customer. If null, then no emails are sent. Minimum value is 7 if set. 
+
 =item token
 
 If specified, card associated with card token will be used 
@@ -188,13 +204,13 @@ Filters to apply to the list.
 
 =item C<max>
 
-Allows up to a max of 50 list items to return. [max value: 50, default: 20]
+Allows up to a max of 50 list items to return. [min value: 0, max value: 50, default: 20]
 
 
 
 =item C<offset>
 
-Used in paging of the list.  This is the start offset of the page. [default: 0]
+Used in paging of the list.  This is the start offset of the page. [min value: 0, default: 0]
 
 
 
@@ -273,7 +289,7 @@ Address of the cardholder if needed. (B<required>)
 
 =item C<card.addressState>
 
-State code (USPS code) of residence of the cardholder. (B<required>) 
+State of residence of the cardholder. For the US, this is a 2-digit USPS code. (B<required>) 
 
 =item C<card.addressZip>
 
@@ -338,11 +354,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.1.0
+1.2.0
 
 =head1 LICENSE
 
-Copyright (c) 2013, 2014 MasterCard International Incorporated
+Copyright (c) 2013 - 2015 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
