@@ -49,13 +49,77 @@ Hash map containing initial values for the object.  Valid keys are:
 
 =over 4
 
+
+
+=item billingAddress.city
+
+Billing address city of the location where the goods or services were supplied. [max length: 255, min length: 2] 
+
+=item billingAddress.country
+
+Billing address country of the location where the goods or services were supplied. [max length: 2, min length: 2] 
+
+=item billingAddress.line1
+
+Billing address line 1 of the location where the goods or services were supplied. [max length: 255] 
+
+=item billingAddress.line2
+
+Billing address line 2 of the location where the goods or services were supplied. [max length: 255] 
+
+=item billingAddress.name
+
+Billing address name of the location where the goods or services were supplied. Will use the customer name if not provided. [max length: 255] 
+
+=item billingAddress.state
+
+Billing address state of the location where the goods or services were supplied. [max length: 255] 
+
+=item billingAddress.zip
+
+Billing address zip of the location where the goods or services were supplied. [max length: 32] 
+
+
+
+=item businessAddress.city
+
+Address city of the business that is sending the invoice. [max length: 255, min length: 2] 
+
+=item businessAddress.country
+
+Address country of the business that is sending the invoice. [max length: 2, min length: 2] 
+
+=item businessAddress.line1
+
+Address line 1 of the business that is sending the invoice. [max length: 255] 
+
+=item businessAddress.line2
+
+Address line 2 of the business that is sending the invoice. [max length: 255] 
+
+=item businessAddress.name
+
+The name of the business that is sending the invoice. [max length: 255] 
+
+=item businessAddress.state
+
+Address state of the business that is sending the invoice. [max length: 255] 
+
+=item businessAddress.zip
+
+Address zip of the business that is sending the invoice. [max length: 32] 
+
 =item currency
 
 Currency code (ISO-4217). Must match the currency associated with your account. [max length: 3, min length: 3, default: USD] 
 
 =item customer
 
-The customer ID of the customer we are invoicing.  This is optional is a name and email are provided 
+The customer ID of the customer we are invoicing.  This is optional if invoiceToCopy or a name and email are provided 
+
+=item customerTaxNo
+
+The tax number or VAT id of the person to whom the goods or services were supplied. [max length: 255] 
 
 =item discountRate
 
@@ -67,17 +131,21 @@ The date invoice payment is due.  If a late fee is provided this will be added t
 
 =item email
 
-The email of the customer we are invoicing.  This is optional if a customer id is provided.  A new customer will be created using the the name and email. 
+The email of the customer we are invoicing.  This is optional if customer or invoiceToCopy is provided.  A new customer will be created using the the name and email. 
 
 =item invoiceId
 
 User defined invoice id. If not provided the system will generate a numeric id. [max length: 255] 
 
+=item invoiceToCopy
+
+The id of an existing invoice to be copied.  This is optional if customer or a name and email are provided 
+
 
 
 =item items.amount
 
-Amount of the invoice item (the smallest unit of your currency). Example: 100 = $1.00USD [min value: 1, max value: 9999900] (B<required>) 
+Amount of the invoice item (the smallest unit of your currency). Example: 100 = $1.00USD [min value: -9999900, max value: 9999900] (B<required>) 
 
 =item items.description
 
@@ -89,7 +157,7 @@ The ID of the invoice this item belongs to.
 
 =item items.product
 
-The product this invoice item refers to. (B<required>) 
+The product this invoice item refers to. 
 
 =item items.quantity
 
@@ -113,7 +181,7 @@ A memo that is displayed to the customer on the invoice payment screen. [max len
 
 =item name
 
-The name of the customer we are invoicing.  This is optional if a customer id is provided.  A new customer will be created using the the name and email. [max length: 50, min length: 2] 
+The name of the customer we are invoicing.  This is optional if customer or invoiceToCopy is provided.  A new customer will be created using the the name and email. [max length: 50, min length: 2] 
 
 =item note
 
@@ -123,29 +191,43 @@ This field can be used to store a note that is not displayed to the customer. [m
 
 User defined reference field. [max length: 255] 
 
-=item shippingAddressLine1
 
-Address Line 1 where the product should be shipped. [max length: 255] 
 
-=item shippingAddressLine2
+=item shippingAddress.city
 
-Address Line 2 where the product should be shipped. [max length: 255] 
+Address city of the location where the goods or services were supplied. [max length: 255, min length: 2] 
 
-=item shippingCity
+=item shippingAddress.country
 
-City where the product should be shipped. [max length: 255, min length: 2] 
+Address country of the location where the goods or services were supplied. [max length: 2, min length: 2] 
 
-=item shippingCountry
+=item shippingAddress.line1
 
-Country where the product should be shipped. [max length: 2, min length: 2] 
+Address line 1 of the location where the goods or services were supplied. [max length: 255] 
 
-=item shippingState
+=item shippingAddress.line2
 
-State where the product should be shipped. [max length: 2, min length: 2] 
+Address line 2 of the location where the goods or services were supplied. [max length: 255] 
 
-=item shippingZip
+=item shippingAddress.name
 
-ZIP code where the product should be shipped. [max length: 9, min length: 5] 
+Address name of the location where the goods or services were supplied. [max length: 255] 
+
+=item shippingAddress.state
+
+Address state of the location where the goods or services were supplied. [max length: 255] 
+
+=item shippingAddress.zip
+
+Address zip of the location where the goods or services were supplied. [max length: 32] 
+
+=item suppliedDate
+
+The date on which the goods or services were supplied. 
+
+=item taxNo
+
+The tax number or VAT id of the person who supplied the goods or services. [max length: 255] 
 
 =item type
 
@@ -190,13 +272,13 @@ Filters to apply to the list.
 
 =item C<max>
 
-Allows up to a max of 50 list items to return. [max value: 50, default: 20]
+Allows up to a max of 50 list items to return. [min value: 0, max value: 50, default: 20]
 
 
 
 =item C<offset>
 
-Used in paging of the list.  This is the start offset of the page. [default: 0]
+Used in paging of the list.  This is the start offset of the page. [min value: 0, default: 0]
 
 
 
@@ -219,6 +301,8 @@ The value maps properties to the sort direction (either C<asc> for ascending or
 
 =item C<status>
 
+=item C<dateCreated>
+
 
 =back
 
@@ -259,6 +343,70 @@ The properties that can be updated are:
 =over 4
 
 
+=item C<billingAddress.city>
+
+Billing address city of the location where the goods or services were supplied. [max length: 255, min length: 2] 
+
+=item C<billingAddress.country>
+
+Billing address country of the location where the goods or services were supplied. [max length: 2, min length: 2] 
+
+=item C<billingAddress.line1>
+
+Billing address line 1 of the location where the goods or services were supplied. [max length: 255] 
+
+=item C<billingAddress.line2>
+
+Billing address line 2 of the location where the goods or services were supplied. [max length: 255] 
+
+=item C<billingAddress.name>
+
+Billing address name of the location where the goods or services were supplied. [max length: 255] 
+
+=item C<billingAddress.state>
+
+Billing address state of the location where the goods or services were supplied. [max length: 255] 
+
+=item C<billingAddress.zip>
+
+Billing address zip of the location where the goods or services were supplied. [max length: 32] 
+
+=item C<businessAddress.city>
+
+Business address city of the business that is sending the invoice. [max length: 255, min length: 2] 
+
+=item C<businessAddress.country>
+
+Business address country of the business that is sending the invoice. [max length: 2, min length: 2] 
+
+=item C<businessAddress.line1>
+
+Business address line 1 of the business that is sending the invoice. [max length: 255] 
+
+=item C<businessAddress.line2>
+
+Business address line 2 of the business that is sending the invoice. [max length: 255] 
+
+=item C<businessAddress.name>
+
+Business address name of the business that is sending the invoice. [max length: 255] 
+
+=item C<businessAddress.state>
+
+Business address state of the business that is sending the invoice. [max length: 255] 
+
+=item C<businessAddress.zip>
+
+Business address zip of the business that is sending the invoice. [max length: 32] 
+
+=item C<currency>
+
+Currency code (ISO-4217). Must match the currency associated with your account. [max length: 3, min length: 3] 
+
+=item C<customerTaxNo>
+
+The tax number or VAT id of the person to whom the goods or services were supplied. [max length: 255] 
+
 =item C<datePaid>
 
 This is the date the invoice was PAID in UTC millis. 
@@ -271,10 +419,18 @@ The discount percent as a decimal e.g. 12.5.  This is used to calculate the disc
 
 The date invoice payment is due.  If a late fee is provided this will be added to the invoice total is the due date has past. 
 
+=item C<email>
+
+The email of the customer we are invoicing.  This is optional if customer or invoiceToCopy is provided.  A new customer will be created using the the name and email. 
+
+
+=item C<invoiceId>
+
+User defined invoice id. If not provided the system will generate a numeric id. [max length: 255] 
 
 =item C<items.amount>
 
-Amount of the invoice item in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 1, max value: 9999900] (B<required>) 
+Amount of the invoice item in the smallest unit of your currency. Example: 100 = $1.00USD [min value: -9999900, max value: 9999900] (B<required>) 
 
 =item C<items.description>
 
@@ -286,7 +442,7 @@ The ID of the invoice this item belongs to.
 
 =item C<items.product>
 
-The Id of the product this item refers to. (B<required>) 
+The Id of the product this item refers to. 
 
 =item C<items.quantity>
 
@@ -302,12 +458,16 @@ The tax ID of the tax charge in the invoice item.
 
 =item C<lateFee>
 
-The late fee amount that will be added to the invoice total is the due date is past due.  Value provided must be in the smallest unit of your currency. Example: 100 = $1.00USD 
+The late fee amount that will be added to the invoice total is the due date is past due.  Value provided must be in the smallest unit of your currency. Example: 100 = $1.00USD [max value: 9999900] 
 
 =item C<memo>
 
 A memo that is displayed to the customer on the invoice payment screen. [max length: 4000] 
 
+=item C<name>
+
+The name of the customer we are invoicing.  This is optional if customer or invoiceToCopy is provided.  A new customer will be created using the the name and email. [max length: 50, min length: 2] 
+
 =item C<note>
 
 This field can be used to store a note that is not displayed to the customer. [max length: 4000] 
@@ -320,34 +480,46 @@ The ID of the payment.  Use this ID to query the /payment API. [max length: 255]
 
 User defined reference field. [max length: 255] 
 
-=item C<shippingAddressLine1>
+=item C<shippingAddress.city>
 
-The shipping address line 1 for the product. [max length: 255] 
+Address city of the location where the goods or services were supplied. [max length: 255, min length: 2] 
 
-=item C<shippingAddressLine2>
+=item C<shippingAddress.country>
 
-The shipping address line 2 for the product. [max length: 255] 
+Address country of the location where the goods or services were supplied. [max length: 2, min length: 2] 
 
-=item C<shippingCity>
+=item C<shippingAddress.line1>
 
-The shipping city for the product. [max length: 255, min length: 2] 
+Address line 1 of the location where the goods or services were supplied. [max length: 255] 
 
-=item C<shippingCountry>
+=item C<shippingAddress.line2>
 
-The shipping country for the product. [max length: 2, min length: 2] 
+Address line 2 of the location where the goods or services were supplied. [max length: 255] 
 
-=item C<shippingState>
+=item C<shippingAddress.name>
 
-The shipping state for the product. [max length: 2, min length: 2] 
+Address name of the location where the goods or services were supplied. [max length: 255] 
 
-=item C<shippingZip>
+=item C<shippingAddress.state>
 
-The shipping ZIP code for the product. [max length: 9, min length: 5] 
+Address state of the location where the goods or services were supplied. [max length: 255] 
+
+=item C<shippingAddress.zip>
+
+Address zip of the location where the goods or services were supplied. [max length: 32] 
 
 =item C<status>
 
 New status of the invoice. 
 
+=item C<suppliedDate>
+
+The date on which the goods or services were supplied. 
+
+=item C<taxNo>
+
+The tax number or VAT id of the person who supplied the goods or services. [max length: 255] 
+
 Authentication is done using the same credentials used when the AccessToken was created.
 
 =back
@@ -366,11 +538,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.1.0
+1.2.0
 
 =head1 LICENSE
 
-Copyright (c) 2013, 2014 MasterCard International Incorporated
+Copyright (c) 2013 - 2015 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
