@@ -51,7 +51,15 @@ Hash map containing initial values for the object.  Valid keys are:
 
 =item amount
 
-Amount of payment for the plan in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 50, max value: 9999900] (B<required>) 
+Amount of payment for the plan in the smallest unit of your currency. Example: 100 = $1.00USD (B<required>) 
+
+=item billingCycle
+
+How the plan is billed to the customer. Values must be AUTO (indefinitely until the customer cancels) or FIXED (a fixed number of billing cycles). [default: AUTO] 
+
+=item billingCycleLimit
+
+The number of fixed billing cycles for a plan. Only used if the billingCycle parameter is set to FIXED. Example: 4 
 
 =item currency
 
@@ -59,12 +67,28 @@ Currency code (ISO-4217) for the plan. Must match the currency associated with y
 
 =item frequency
 
-Frequency of payment for the plan. Example: Monthly (B<required>) 
+Frequency of payment for the plan. Used in conjunction with frequencyPeriod. Valid values are "DAILY", "WEEKLY", "MONTHLY" and "YEARLY". [default: MONTHLY] (B<required>) 
+
+=item frequencyPeriod
+
+Period of frequency of payment for the plan. Example: if the frequency is weekly, and periodFrequency is 2, then the subscription is billed bi-weekly. [min value: 1, default: 1] (B<required>) 
 
 =item name
 
 Name of the plan [max length: 50, min length: 2] (B<required>) 
 
+=item renewalReminderLeadDays
+
+If set, how many days before the next billing cycle that a renewal reminder is sent to the customer. If null, then no emails are sent. Minimum value is 7 if set. 
+
+=item trialPeriod
+
+Plan free trial period selection.  Must be Days, Weeks, or Month [default: NONE] (B<required>) 
+
+=item trialPeriodQuantity
+
+Quantity of the trial period.  Must be greater than 0 and a whole number. [min value: 1] 
+
 
 =back
 
@@ -104,13 +128,13 @@ Filters to apply to the list.
 
 =item C<max>
 
-Allows up to a max of 50 list items to return. [max value: 50, default: 20]
+Allows up to a max of 50 list items to return. [min value: 0, max value: 50, default: 20]
 
 
 
 =item C<offset>
 
-Used in paging of the list.  This is the start offset of the page. [default: 0]
+Used in paging of the list.  This is the start offset of the page. [min value: 0, default: 0]
 
 
 
@@ -194,11 +218,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.1.0
+1.2.0
 
 =head1 LICENSE
 
-Copyright (c) 2013, 2014 MasterCard International Incorporated
+Copyright (c) 2013 - 2015 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
