@@ -42,7 +42,7 @@ Hash map containing initial values for the object.  Valid keys are:
 
 =item amount
 
-Amount of the refund in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 1, max value: 9999900] (B<required>) 
+Amount of the refund in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 1] (B<required>) 
 
 =item payment
 
@@ -61,6 +61,16 @@ Custom reference field to be used with outside systems.
 An identifier that can be sent to uniquely identify a refund request to facilitate retries due to I/O related issues. This identifier must be unique for your account (sandbox or live) across all of your refunds. If supplied, we will check for a refund on your account that matches this identifier. If found we will return an identical response to that of the original request. [max length: 50, min length: 1] 
 
 
+
+=item statementDescription.name
+
+Merchant name. (B<required>) 
+
+=item statementDescription.phoneNumber
+
+Merchant contact phone number. 
+
+
 =back
 
 =item C<$auth>
@@ -93,13 +103,13 @@ Filters to apply to the list.
 
 =item C<max>
 
-Allows up to a max of 50 list items to return. [max value: 50, default: 20]
+Allows up to a max of 50 list items to return. [min value: 0, max value: 50, default: 20]
 
 
 
 =item C<offset>
 
-Used in paging of the list.  This is the start offset of the page. [default: 0]
+Used in paging of the list.  This is the start offset of the page. [min value: 0, default: 0]
 
 
 
@@ -164,11 +174,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.1.0
+1.2.0
 
 =head1 LICENSE
 
-Copyright (c) 2013, 2014 MasterCard International Incorporated
+Copyright (c) 2013 - 2015 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
