@@ -51,7 +51,15 @@ Hash map containing initial values for the object.  Valid keys are:
 
 =item amount
 
-Amount of the payment in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 50, max value: 9999900] 
+Amount of the payment in the smallest unit of your currency. Example: 100 = $1.00USD 
+
+=item billingCycle
+
+How the plan is billed to the customer. Values must be AUTO (indefinitely until the customer cancels) or FIXED (a fixed number of billing cycles). [default: AUTO] 
+
+=item billingCycleLimit
+
+The number of fixed billing cycles for a plan. Only used if the billingCycle parameter is set to FIXED. Example: 4 
 
 =item coupon
 
@@ -67,7 +75,11 @@ Customer that is enrolling in the subscription.
 
 =item frequency
 
-Frequency of payment for the plan. Example: Monthly 
+Frequency of payment for the plan. Used in conjunction with frequencyPeriod. Valid values are "DAILY", "WEEKLY", "MONTHLY" and "YEARLY". 
+
+=item frequencyPeriod
+
+Period of frequency of payment for the plan. Example: if the frequency is weekly, and periodFrequency is 2, then the subscription is billed bi-weekly. 
 
 =item name
 
@@ -81,6 +93,10 @@ The ID of the plan that should be used for the subscription.
 
 Quantity of the plan for the subscription. [min value: 1] 
 
+=item renewalReminderLeadDays
+
+If set, how many days before the next billing cycle that a renewal reminder is sent to the customer. If null, then no emails are sent. Minimum value is 7 if set. 
+
 
 =back
 
@@ -120,13 +136,13 @@ Filters to apply to the list.
 
 =item C<max>
 
-Allows up to a max of 50 list items to return. [max value: 50, default: 20]
+Allows up to a max of 50 list items to return. [min value: 0, max value: 50, default: 20]
 
 
 
 =item C<offset>
 
-Used in paging of the list.  This is the start offset of the page. [default: 0]
+Used in paging of the list.  This is the start offset of the page. [min value: 0, default: 0]
 
 
 
@@ -183,7 +199,15 @@ The properties that can be updated are:
 
 =item C<amount>
 
-Amount of the payment in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 50, max value: 9999900] 
+Amount of the payment in the smallest unit of your currency. Example: 100 = $1.00USD 
+
+=item C<billingCycle>
+
+How the plan is billed to the customer. Values must be AUTO (indefinitely until the customer cancels) or FIXED (a fixed number of billing cycles). [default: AUTO] 
+
+=item C<billingCycleLimit>
+
+The number of fixed billing cycles for a plan. Only used if the billingCycle parameter is set to FIXED. Example: 4 
 
 =item C<coupon>
 
@@ -195,7 +219,11 @@ Currency code (ISO-4217). Must match the currency associated with your account.
 
 =item C<frequency>
 
-Frequency of payment for the plan. Example: Monthly 
+Frequency of payment for the plan. Used in conjunction with frequencyPeriod. Valid values are "DAILY", "WEEKLY", "MONTHLY" and "YEARLY". 
+
+=item C<frequencyPeriod>
+
+Period of frequency of payment for the plan. Example: if the frequency is weekly, and periodFrequency is 2, then the subscription is billed bi-weekly. [min value: 1] 
 
 
 =item C<name>
@@ -214,6 +242,10 @@ Whether to prorate existing subscription. [default: true] (B<required>)
 
 Quantity of the plan for the subscription. [min value: 1] 
 
+=item C<renewalReminderLeadDays>
+
+If set, how many days before the next billing cycle that a renewal reminder is sent to the customer. If null or 0, no emails are sent. Minimum value is 7 if set. 
+
 Authentication is done using the same credentials used when the AccessToken was created.
 
 =back
@@ -232,11 +264,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.1.0
+1.2.0
 
 =head1 LICENSE
 
-Copyright (c) 2013, 2014 MasterCard International Incorporated
+Copyright (c) 2013 - 2015 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
